# ===============================================================================
# EXAMPLE
# Demonstrates how to access the XTREST-API without using the API-Wrapper
# ===============================================================================

import requests
import json


# Base-URL of XTWeb-Api
apiurl = "http://localhost:9000/api/"
apikey = "6D12E349-331A-4BBF-B630-A275A56308BC"
API_USERNAME = "demo"
API_PASSWORD = "demo"

# Endpoint: Login
url = apiurl + "login"

headers = {
    "content-type": "application/json",
    "accept": "application/json",
    "apikey": apikey,
    "jwtusername": "demo",
    "jwtpassword": "demo"
}

response = requests.request("POST", url, headers=headers, auth=(API_USERNAME, API_PASSWORD))

print(f"\nAUTHENTICATE with POST {url} : {headers} ")
print(f"{response.status_code}: {response.reason}")
print(response.text)

if not response: exit
data = json.loads(response.text)

# JWT Token to send with every header
try:
    token = data['token']
    print("\nToken: " + token)

    # Get User list

    # Endpoint: Login
    url = apiurl + "users"

    headers = {
    "content-type": "application/json",
    "accept": "application/json, text/plain, */*",
    "Accept-Encoding": "gzip, deflate, br",
    "apikey": apikey,
    "authentication": "Bearer " + token,
    "Access-Control-Request-Headers": "authentication"
    }

    params = {
    "state":1,              # Only active users
    "sortdirection":"asc",  # Default: asc
    "pageNumber":0,         # Default: 0
    "pageSize":10           # Default: 10
    }

    response = requests.request("GET", url, json=params, headers=headers, auth=(API_USERNAME, API_PASSWORD))

    print(f"\nGET {url}?{params}")
    print(f"\n{response.status_code}: {response.reason}")
    print(response.text)

    if not response:
        exit
    
    data = response.json()
    firstname = data[0]['firstname']
    print('=> Firstname: ', firstname)

    # Get user_nr of first user in the list
    user_nr = data[0]['user_nr']

    # Get User ======================================================

    # Endpoint: user
    url = apiurl + "users" + "/" + user_nr

    response = requests.request("GET", url, headers=headers, auth=(API_USERNAME, API_PASSWORD))

    print(f"\nGET {url}")
    print(f"\n{response.status_code}: {response.reason}")
    print(response.text)
    if response:
        data = response.json()
        firstname = data['firstname']
        print('=> Firstname: ', firstname)

    # Get list of timestamps for user ===============================

    # Endpoint: timestamps
    url = apiurl + "times"

    params = {
    "user_nr":user_nr   # Only times of current user
    }

    response = requests.request("GET", url, json=params, headers=headers, auth=(API_USERNAME, API_PASSWORD))

    print(f"\nGET {url}?{params}")
    print(f"\n{response.status_code}: {response.reason}")
    print(response.text)

    if response:
        data = response.json()
        # Pick first timestamp from list
        minutesneeded = data[0]['minutesneeded']
        print('=> minutesneeded: ', minutesneeded)
    
except KeyError:
    print(f"\nERROR: AUTHENTICATION FAILED")
