"""@package URLs

    A Python3 class that allows access to all of the functionality in the
    Xpert-Timer XTWEB/XTCLOURSERVER API.

    This package attempts to stay on top of changes to the API and allow an
    easy to user interface with the XTWEB API. The API does no formatting
    for the user. The API responses will be returned as the raw JSON.

    This API was built with the developer in mind and should allow a developer
    to build applications around the XTWEB API without having to deal with
    accessing and managing the requests and responses.

"""
class URLs:
    """ The URLs class will handle all of the URLs. The purpose of this class is
        to essentially store and serve all of the URL strings useful to the
        XTWEB API.

        There is no processing of the URLs or the URL parameters done in this class
        all of that logic is handled in the XTRESTAPI class.
    """
    def __init__(self, baseUrl = ""):
        """The URLs class constructor which defines all of the URLs used by the API.

            When adding new API functionality the URL needs to be added here.
            Examples abound of the format used by this implementation of the API.

            @param self - the object pointer
        """

        if baseUrl == "":
            baseUrl = "http://localhost:9000/api/"

        self.base_url = baseUrl
        
        # login
        self.login = "login"

        # system
        self.system = "system"

        # user
        self.users = "users"
        self.user = "users/{id}".format(id="{id}")

        # client
        self.clients = "clients"
        self.client = "clients/{id}".format(id="{id}")

        # project
        self.projects = "projects"
        self.project = "projects/{id}".format(id="{id}")

        # task
        self.tasks = "tasks"
        self.task = "tasks/{id}".format(id="{id}")

        # times
        self.times = "times"
        self.time = "times/{id}".format(id="{id}")

        # JSON-RPC
        self.jrpc = "jsonrpc"


    def base_url(self):
        """Returns the API request endpoint.
            @param self - the object pointer
        """
        return self.base_url

    """
        JSON RPC
    """
    def jrpc_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.jrpc


    """
        System
    """
    def system_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.system

    """
        Login
    """
    def login_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.login

    """
        Users
    """
    def users_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.users

    def user_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.user

    """
        Clients
    """
    def clients_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.clients
    def client_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.client

    """
        Projects
    """
    def projects_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.projects

    def project_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.project

    """
        Tasks
    """
    def tasks_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.tasks

    def task_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.task

    """
        Times
    """
    def timestamps_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.times

    def timestamp_url(self):
        """Combines the request endpoint and accounts API URLs
            @param self - the object pointer
        """
        return self.base_url + self.time
